@@ -9,20 +9,17 @@
 """
 import time,sys,os
 from DateTime import *
-from CommandLine import Application,Option,NoDefault
+from CommandLine import Application,ArgumentOption
 
 class Alarm(Application):
 
     header = "Simple Forking Alarm"
-    options = [Option('-s',
-		      'set the alarm to now + arg seconds',
-		      NoDefault),
-	       Option('-m',
-		      'set the alarm to now + arg minutes',
-		      NoDefault),
-	       Option('-a',
-		      'set the alarm to ring at arg (hh:mm)',
-		      NoDefault)
+    options = [ArgumentOption('-s',
+                              'set the alarm to now + arg seconds'),
+	       ArgumentOption('-m',
+                              'set the alarm to now + arg minutes'),
+	       ArgumentOption('-a',
+                              'set the alarm to ring at arg (hh:mm)'),
 	       ]
     version = '0.1'
 
@@ -49,8 +46,8 @@ def alarm():
     """
     for i in range(10):
 	sys.stdout.write('\007')
+	sys.stdout.flush()
 	time.sleep(0.2)
 
-
 if __name__ == '__main__':
     Alarm()
